@@ -9,7 +9,12 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+#
+# -*- coding: utf-8 -*-
 
-from marquez_client.client import MarquezClient
-from marquez_client.client_wo import MarquezWriteOnlyClient
-from marquez_client.clients import Clients
+__author__ = """Marquez Project"""
+__version__ = "0.14.0"
+
+from marquez_client.client import MarquezClient              # noqa: F401
+from marquez_client.client_wo import MarquezWriteOnlyClient  # noqa: F401
+from marquez_client.clients import Clients                   # noqa: F401
