@@ -13,14 +13,15 @@
 import datetime
 import logging
 
+import marquez_client
+
 from six.moves.urllib.parse import quote
 
-from marquez_client.version import VERSION
 from .models import (DatasetType, JobType)
 from .utils import Utils
 
 _API_PATH = '/api/v1'
-_USER_AGENT = f'marquez-python/{VERSION}'
+_USER_AGENT = f'marquez-python/{marquez_client.__version__}'
 _HEADERS = {'User-Agent': _USER_AGENT}
 
 log = logging.getLogger(__name__)
